Saqqaf, Keeper of the Grand TempleCon of Set - Northeast Regional Qualifier 2006 Providence, Rhode Island January 28th 2006 3R+F 39 players Jonathan Scherer Slippery When Wet This deck is an old friend of mine. It has been heavily modified over the years, with the most recent modification being the addition of dominate to the deck. The Gangrel were the first clan that I really got to work in casual play, many years ago. I tried it a few times in tournaments but it lacked the speed necessary to win a table. After the addition of dominate for some added pressure it has been much more effective, with several strong showings. While a good position and some luck was key in winning the day, this deck showed itself to be a strong competitor. Crypt (12 cards, min=13, max=35, avg=6) --------------------------------------- 3x Ingrid Rossler 9 ANI FOR PRO dom prince Gangrel:2 2x Caitlin 6 ANI PRO aus dom bishop Gangrel antitribu:2 2x Chandler Hungerford 3 PRO Gangrel:2 1x Faruq 8 ANI PRO dom for pot Gangrel:2 1x Iliana 7 DOM FOR PRO tha Gangrel:2 1x Camille Devereux, The Raven 5 FOR PRO ani Gangrel:1 1x Ramona 4 for pro Gangrel:2 1x Ricki Van Demsi 3 for pro Gangrel:1 Library (90 cards) Master (15) 1x Barrens, The 3x Blood Doll 1x Club Zombie 3x Dominate 1x Dreams of the Sphinx 2x Ecoterrorists 1x KRCG News Radio 1x Smiling Jack, The Anarch 1x WMRH Talk Radio 1x Zoo Hunting Ground Action (9) 1x Aranthebes, The Immortal 2x Computer Hacking 4x Govern the Unaligned 2x Restoration Ally (4) 1x Procurer 3x Renegade Garou Equipment (1) 1x Palatial Estate Retainer (4) 1x Mr. Winthrop 3x Raven Spy Action Modifier (14) 3x Conditioning 1x Day Operation 5x Earth Control 1x Foreshadowing Destruction 4x Freak Drive Reaction (20) 5x Cats' Guidance 4x Deflection 1x Instinctive Reaction 2x Second Tradition: Domain 8x Wake with Evening's Freshness Combat (23) 5x Claws of the Dead 13x Earth Meld 5x Form of Mist